@@ -141,7 +141,7 @@ class SlideData:
                 key: val for key, val in stain_type_dict.items() if val is not None
             }
             if stain_type_dict:
-                slide_type = pathml.core.types.SlideType(**stain_type_dict)
+                slide_type = pathml.core.slide_types.SlideType(**stain_type_dict)
 
         # get name from filepath if no name is provided
         if name is None and filepath is not None:
@@ -320,14 +320,6 @@ class SlideData:
                 pipeline.apply(tile)
                 self.tiles.add(tile)
 
-    @property
-    def tile_dataset(self):
-        """
-        Creates a Pytorch Dataset object over tiles. Each item contains a (Tile, labels) pair where labels is the
-        slide-level labels
-        """
-        return self._create_tile_dataset(self)
-
     @property
     def shape(self):
         """
@@ -342,26 +334,6 @@ class SlideData:
         else:
             return self.slide.get_image_shape()
 
-    @staticmethod
-    def _create_tile_dataset(slidedata):
-        # create a pytorch dataset for tiles, also with slide-level labels
-        class TileDataset(Dataset):
-            def __init__(self, slidedata):
-                if slidedata.tiles is None:
-                    raise ValueError(
-                        "Can't create tile dataset because self.tiles is None"
-                    )
-                self.tiles = slidedata.tiles
-                self.labels = slidedata.labels
-
-            def __len__(self):
-                return len(self.tiles)
-
-            def __getitem__(self, ix):
-                return self.tiles[ix], self.labels
-
-        return TileDataset(slidedata)
-
     def generate_tiles(self, shape=3000, stride=None, pad=False, **kwargs):
         """
         Generator over Tile objects containing regions of the image.
